Configuration
=============

View automated_install.md for configuration instructions.

Flowchart
=========

The following is the flow of actions when initiating a reading with Raspi-Sump


![Flow Chart](https://www.linuxnorth.org/raspi-sump/images/raspi_sump_flowchart.jpg)
